# jobs_scraper (WIP)


[![Build Status](https://travis-ci.com/vittoriotriassi/jobs_scraper.svg?branch=master)](https://travis-ci.com/vittoriotriassi/jobs_scraper)

jobs_scraper is a simple job postings scraper for Indeed.
